==> react-inline-editable-field-1.0.1.tgz: package/react-inline-editable-field.jsx <==
import React  from 'react';
export default class ReactInlineEditableField extends React.Component {

  constructor(props, context) {
    super(props, context);
    this.props = props;
    this.state = {
      editing: false
    }
  }

  onBlur() {
    if(typeof this.props.onBlur === 'function') {
      try {
        this.props.onBlur(this.state.inputValue, this.state.inputValue != this.props.content)
      } catch(e) {
        console.error(e);
      }
    }
    this.setState({editing: false})
  }

  handleKeyUp(e) {
   this.setState({inputValue: e.target.value})
    if(e.key === "Enter") {
      this.onBlur();
    }
  }

  createOptions(option){
    return  <option value={option}>{option}</option>
  }
  render() {
    var options = this.props.options && this.props.options.map(function(option,idx){
      return  <option value={option}>{option}</option>
    });

    if(!this.props.notEditable && this.state.editing) {
      var field = <input
        type="text"
        autoFocus
        placeholder={this.props.placeholder}
        defaultValue={this.props.content}
        style={this.props.inputStyle}
        onKeyUp={(e) => { this.handleKeyUp(e) }}
      />
    } else {
      if(typeof this.props.displayRender === 'function') {
        var displayField = this.props.displayRender(this.props.content);
      } else if(!this.props.content) {
        var displayField = this.props.displayPlaceholder;
      }
      else {
        var displayField = this.props.content;
      }
      var field = <span className={this.props.className}>{displayField}</span>
    }

    return (
      <div style={this.props.style} className={this.props.className || "common-editable-field"} onClick={(e) => { this.setState({editing: true})} } onBlur={() => { this.onBlur()}}>
        {field}
      </div>
    );
  }
}

==> react-inline-editable-field-1.0.6.tgz: package/react-inline-editable-field.jsx <==
import React  from 'react';
export default class ReactInlineEditableField extends React.Component {

  constructor(props, context) {
    super(props, context);
    this.props = props;
    this.state = {
      editing: false
    }
  }

  onBlur() {
    if(typeof this.props.onBlur === 'function') {
      try {
        this.props.onBlur(this.state.inputValue, this.state.inputValue != this.props.content)
      } catch(e) {
        console.error(e);
      }
    }
    this.setState({editing: false})
  }

  handleKeyUp(e) {
   this.setState({inputValue: e.target.value})
    if(e.key === "Enter") {
      this.onBlur();
    }
  }

  createOptions(option){
    return  <option value={option}>{option}</option>
  }
  render() {
    var options = this.props.options && this.props.options.map(function(option,idx){
      return  <option value={option}>{option}</option>
    });

    if(!this.props.notEditable && this.state.editing) {
      if(this.props.inputType == "textarea") {
        var field = <textarea
          autoFocus
          rows={this.props.rows}
          placeholder={this.props.placeholder}
          defaultValue={this.props.content}
          style={this.props.inputStyle}
          onKeyUp={(e) => { this.handleKeyUp(e) }}
        />
      }else{
        var field = <input
          type="text"
          autoFocus
          placeholder={this.props.placeholder}
          defaultValue={this.props.content}
          style={this.props.inputStyle}
          onKeyUp={(e) => { this.handleKeyUp(e) }}
        />
      }
    } else {
      if(typeof this.props.displayRender === 'function') {
        var displayField = this.props.displayRender(this.props.content);
      } else if(!this.props.content) {
        var displayField = this.props.displayPlaceholder;
      }
      else {
        var displayField = this.props.content;
      }
      var field = <span className={this.props.className}>{displayField}</span>
    }

    return (
      <div style={this.props.style} className={this.props.className} onClick={(e) => { this.setState({editing: true})} } onBlur={() => { this.onBlur()}}>
        {field}
      </div>
    );
  }
}
